@@ -45,6 +45,7 @@ class StatsHandler(tornado.web.RequestHandler):
 
 
 def run():
+    import sys
     import argparse
     import ardaemon
 
@@ -54,7 +55,7 @@ def run():
     parser.add_argument("-p", metavar="port", type=int, default=6521, dest="port", help="listening port")
     parser.add_argument("-d", metavar="path", type=str, dest="path", default="/tmp/leveldb", help="database location")
 
-    with ardaemon.Daemon(name="leveldb", parser=parser) as daemon:
+    with ardaemon.Daemon(name="leveldb", parser=parser, stdout=sys.stdout, stderr=sys.stderr) as daemon:
         import tornado.httpserver
         import tornado.ioloop
 
